@@ -185,9 +185,14 @@ struct _EvView {
 	GList             *window_children;
 	EvViewWindowChild *window_child_focus;
 	EvMapping         *focus_annotation;
+	gboolean           adding_annot;
+	EvAnnotationType   adding_annot_type;
 
 	/* Synctex */
 	EvMapping *synctex_result;
+
+	/* Accessibility */
+	gboolean a11y_enabled;
 };
 
 struct _EvViewClass {
@@ -205,6 +210,9 @@ struct _EvViewClass {
 	void    (*selection_changed)      (EvView         *view);
 	void    (*sync_source)            (EvView         *view,
 					   EvSourceLink   *link);
+	void    (*annot_added)            (EvView         *view,
+					   EvAnnotation   *annot);
+	void    (*layers_changed)         (EvView         *view);
 };
 
 void _get_page_size_for_scale_and_rotation (EvDocument *document,
